@@ -779,6 +779,12 @@ userOutput <- function(id, tag = shiny::tags$li) {
 #' @family user outputs
 #' @rdname dashboardUser
 #' @export
-renderUser <- shiny::renderUI
+renderUser <- function(expr, env = parent.frame(), quoted = FALSE, outputArgs = list()) {
+  if (!quoted) {
+    expr <- substitute(expr)
+    quoted <- TRUE
+  }
+  shiny::renderUI(expr, env = env, quoted = quoted, outputArgs = outputArgs)
+}
 
 globalVariables("func")
\ No newline at end of file
