@@ -725,4 +725,7 @@ bs4SidebarUserPanel <- function(name, image = NULL) {
 #'   )
 #' }
 #' @export
-updatebs4TabItems <- shiny::updateTabsetPanel
\ No newline at end of file
+updatebs4TabItems <- function (session = shiny::getDefaultReactiveDomain(), inputId, selected = NULL) {
+  shiny::updateTabsetPanel(session = session, inputId, selected = selected)
+}
+
