@@ -253,4 +253,10 @@ menuItemOutput <- function(outputId) {
 #'
 #'   shinyApp(ui, server)
 #' }
-renderMenu <- shiny::renderUI
\ No newline at end of file
+renderMenu <- function (expr, env = parent.frame(), quoted = FALSE, outputArgs = list()) {
+  shiny::renderUI(expr, env = env, quoted = quoted, outputArgs = outputArgs)
+}
+  
+  
+
+
